summaryrefslogtreecommitdiffstats
path: root/lib/kross/test/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kross/test/main.cpp')
-rw-r--r--lib/kross/test/main.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/lib/kross/test/main.cpp b/lib/kross/test/main.cpp
index 31b4f579..42198201 100644
--- a/lib/kross/test/main.cpp
+++ b/lib/kross/test/main.cpp
@@ -34,9 +34,9 @@
#include "testwindow.h"
#include "testplugin.h"
-// Qt
-#include <qstring.h>
-#include <qfile.h>
+// TQt
+#include <tqstring.h>
+#include <tqfile.h>
// KDE
#include <kinstance.h>
@@ -64,7 +64,7 @@ static KCmdLineOptions options[] =
{ 0, 0, 0 }
};
-void runInterpreter(const QString& interpretername, const QString& scriptcode)
+void runInterpreter(const TQString& interpretername, const TQString& scriptcode)
{
try {
@@ -91,10 +91,10 @@ void runInterpreter(const QString& interpretername, const QString& scriptcode)
//TESTCASE
TestObject* testobject = new TestObject(app, scriptcontainer);
- manager->addQObject( testobject );
+ manager->addTQObject( testobject );
/*TestAction* testaction =*/ new TestAction(scriptcontainer);
- //manager->addQObject( testaction );
+ //manager->addTQObject( testaction );
/*Kross::Api::Object* o =*/ scriptcontainer->execute();
@@ -105,23 +105,23 @@ void runInterpreter(const QString& interpretername, const QString& scriptcode)
/*
Kross::Api::Object* testclassinstance = scriptcontainer->classInstance("testClass");
if(testclassinstance) {
- QValueList<Kross::Api::Object*> ll;
+ TQValueList<Kross::Api::Object*> ll;
Kross::Api::Object* instancecallresult = testclassinstance->call("testClassFunction1", Kross::Api::List::create(ll));
- //krossdebug( QString("testClass.testClassFunction1 returnvalue => '%1'").arg( instancecallresult.toString() ) );
+ //krossdebug( TQString("testClass.testClassFunction1 returnvalue => '%1'").tqarg( instancecallresult.toString() ) );
}
*/
/*
- // Connect QObject signal with scriptfunction.
- scriptcontainer->connect(testobject, SIGNAL(testSignal()), "testobjectCallback");
- scriptcontainer->connect(testobject, SIGNAL(testSignalString(const QString&)), "testobjectCallbackWithParams");
+ // Connect TQObject signal with scriptfunction.
+ scriptcontainer->connect(testobject, TQT_SIGNAL(testSignal()), "testobjectCallback");
+ scriptcontainer->connect(testobject, TQT_SIGNAL(testSignalString(const TQString&)), "testobjectCallbackWithParams");
// Call the testSlot to emit the testSignal.
testobject->testSlot();
*/
}
catch(Kross::Api::Exception::Ptr e) {
- std::cout << QString("EXCEPTION %1").arg(e->toString()).latin1() << std::endl;
+ std::cout << TQString("EXCEPTION %1").tqarg(e->toString()).latin1() << std::endl;
}
/*TESTCASE
@@ -132,7 +132,7 @@ void runInterpreter(const QString& interpretername, const QString& scriptcode)
sc2->execute();
}
catch(Kross::Api::Exception& e) {
- krossdebug( QString("EXCEPTION type='%1' description='%2'").arg(e.type()).arg(e.description()) );
+ krossdebug( TQString("EXCEPTION type='%1' description='%2'").tqarg(e.type()).tqarg(e.description()) );
}
//delete sc2;
*/
@@ -159,12 +159,12 @@ int main(int argc, char **argv)
KCmdLineArgs::addCmdLineOptions(options);
KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
- QString interpretername = args->getOption("interpreter");
- QString scriptfilename = args->getOption("scriptfile");
+ TQString interpretername = args->getOption("interpreter");
+ TQString scriptfilename = args->getOption("scriptfile");
- QFile f(QFile::encodeName(scriptfilename));
+ TQFile f(TQFile::encodeName(scriptfilename));
if(f.exists() && f.open(IO_ReadOnly)) {
- QString scriptcode = f.readAll();
+ TQString scriptcode = f.readAll();
f.close();
if( args->isSet("gui") ) {
@@ -181,7 +181,7 @@ int main(int argc, char **argv)
}
}
else {
- Kross::krosswarning( QString("Failed to load scriptfile: %1").arg(scriptfilename) );
+ Kross::krosswarning( TQString("Failed to load scriptfile: %1").tqarg(scriptfilename) );
result = -1;
}